@@ -29,7 +29,8 @@ from django.db.models import Q
 from rest_framework import generics, status
 from rest_framework.response import Response as HttpResponse
 
-from .. import signals
+from .. import settings, signals
+from ..compat import six
 from ..mixins import AccountMixin
 from ..models import PortfolioDoubleOptIn
 from .serializers import (PortfolioOptInSerializer,
@@ -92,13 +93,15 @@ class PortfoliosAPIView(SmartPortfolioListMixin, generics.ListAPIView):
             "next": null,
             "previous": null,
             "results": [
-                {
-                    "account": "supplier-1",
-                    "grantee": "energy-utility",
-                    "endst_at": "2018-01-01T00:00:00Z",
-                    "accept_api_url":"http://localhost:8000/api/energy-utility/\
-portfolios/0123456789abcdef"
-                 }
+              {
+                "grantee": "energy-utility",
+                "account": "supplier-1",
+                "campaign": "sustainability",
+                "ends_at": "2022-01-01T00:00:00Z",
+                "state": "request-initiated",
+                "api_accept": "/api/supplier-1/portfolios/requests/\
+0000000000000000000000000000000000000002/"
+              }
             ]
         }
     """
@@ -124,7 +127,7 @@ class PortfoliosGrantsAPIView(SmartPortfolioListMixin,
 
     .. code-block:: http
 
-        GET /api/energy-utility/portfolios/grants HTTP/1.1
+        GET /api/supplier-1/portfolios/grants HTTP/1.1
 
     responds
 
@@ -136,16 +139,19 @@ class PortfoliosGrantsAPIView(SmartPortfolioListMixin,
             "previous": null,
             "results": [
                 {
-                    "account": "supplier-1",
-                    "grantee": "energy-utility",
-                    "endst_at": "2018-01-01T00:00:00Z",
-                    "accept_api_url":"http://localhost:8000/api/energy-utility/\
-portfolios/0123456789abcdef"
+                  "grantee": "water-utility",
+                  "account": "supplier-1",
+                  "campaign": "sustainability",
+                  "ends_at": "2022-01-01T00:00:00Z",
+                  "state": "grant-initiated",
+                  "api_accept": "/api/water-utility/portfolios/grants\
+/0000000000000000000000000000000000000003/"
                  }
             ]
         }
     """
     serializer_class = PortfolioOptInSerializer
+    lookup_field = settings.ACCOUNT_LOOKUP_FIELD
 
     def get_queryset(self):
         return PortfolioDoubleOptIn.objects.filter(
@@ -193,20 +199,38 @@ portfolios/0123456789abcdef"
         grantee_data = {}
         grantee_data.update(serializer.validated_data['grantee'])
         campaign = serializer.validated_data.get('campaign')
+
+        # Django1.11: we need to remove invalid fields when creating
+        # a new grantee account otherwise Django1.11 will raise an error.
+        # This is not the case with Django>=3.2
+        account_model = get_account_model()
+        lookups = {self.lookup_field: grantee_data.pop('slug')}
+        invalid_fields = []
+        model_fields = set([
+            field.name for field in account_model._meta.get_fields()])
+        for field_name in six.iterkeys(grantee_data):
+            if field_name not in model_fields:
+                invalid_fields += [field_name]
+        for field_name in invalid_fields:
+            grantee_data.pop(field_name)
+        grantee, unused_created = account_model.objects.get_or_create(
+            defaults=grantee_data, **lookups)
+
         accounts = serializer.validated_data.get('accounts', [])
+        if not accounts:
+            accounts = [self.account]
         defaults = {
             'initiated_by': self.request.user,
             'state': PortfolioDoubleOptIn.OPTIN_GRANT_INITIATED,
             'ends_at': created_at
         }
-        grantee_slug = grantee_data.pop('slug')
-        grantee, unused_created = get_account_model().objects.get_or_create(
-            slug=grantee_slug, defaults=grantee_data)
-        if accounts:
+        with transaction.atomic():
             for account in accounts:
                 # XXX assert self.account has access to `account`
                 portfolio, unused_created = \
-                    PortfolioDoubleOptIn.objects.update_or_create(
+                    PortfolioDoubleOptIn.objects.exclude(
+                        state=PortfolioDoubleOptIn.OPTIN_REQUEST_DENIED
+                    ).update_or_create(
                         account=account,
                         grantee=grantee,
                         campaign=campaign,
@@ -214,15 +238,6 @@ portfolios/0123456789abcdef"
                 signals.portfolio_grant_initiated.send(sender=__name__,
                     portfolio=portfolio, request=self.request)
 
-        else:
-            serializer.instance = PortfolioDoubleOptIn.objects.update_or_create(
-                account=self.account,
-                grantee=grantee,
-                campaign=campaign,
-                defaults=defaults)
-            signals.portfolio_grant_initiated.send(sender=__name__,
-                portfolio=serializer.instance, request=self.request)
-
 
 class PortfoliosGrantAcceptAPIView(AccountMixin, generics.DestroyAPIView):
     """
@@ -312,17 +327,36 @@ class PortfoliosRequestsAPIView(SmartPortfolioListMixin,
     .. code-block:: json
 
         {
-            "count": 1,
+            "count": 3,
             "next": null,
             "previous": null,
             "results": [
-                {
-                    "account": "supplier-1",
-                    "grantee": "energy-utility",
-                    "endst_at": "2018-01-01T00:00:00Z",
-                    "accept_api_url":"http://localhost:8000/api/energy-utility/\
-portfolios/0123456789abcdef"
-                 }
+              {
+                "grantee": "energy-utility",
+                "account": "supplier-1",
+                "campaign": "sustainability",
+                "ends_at": "2022-01-01T00:00:00Z",
+                "state": "request-denied",
+                "api_accept": null
+              },
+              {
+                "grantee": "energy-utility",
+                "account": "supplier-1",
+                "campaign": "sustainability",
+                "ends_at": "2022-01-01T00:00:00Z",
+                "state": "request-initiated",
+                "api_accept": "/api/supplier-1/portfolios/requests/\
+0000000000000000000000000000000000000002/"
+              },
+              {
+                "grantee": "energy-utility",
+                "account": "andy-shop",
+                "campaign": "sustainability",
+                "ends_at": "2022-01-01T00:00:00Z",
+                "state": "request-initiated",
+                "api_accept": "/api/andy-shop/portfolios/requests/\
+0000000000000000000000000000000000000004/"
+              }
             ]
         }
     """
@@ -365,25 +399,33 @@ portfolios/0123456789abcdef"
         return super(PortfoliosRequestsAPIView, self).get_serializer_class()
 
     def perform_create(self, serializer):
+        account_model = get_account_model()
         defaults = {
             'state': PortfolioDoubleOptIn.OPTIN_REQUEST_INITIATED,
             'ends_at': datetime_or_now(),
             'initiated_by': self.request.user
         }
         accounts = serializer.validated_data['accounts']
-        for account in accounts:
-            account, unused_created = get_account_model().objects.get_or_create(
-                slug=account.get('slug'),
-                defaults={
-                    'email': account.get('email')
-                })
-            portfolio, unused_created = \
-                PortfolioDoubleOptIn.objects.update_or_create(
-                    grantee=self.account,
-                    account=account,
-                    campaign=serializer.validated_data.get('campaign'),
-                    defaults=defaults)
-            signals.portfolio_requests_initiated.send(sender=__name__,
+        requests_initiated = []
+        with transaction.atomic():
+            for account in accounts:
+                lookups = {self.lookup_field: account.get('slug')}
+                account, unused_created = account_model.objects.get_or_create(
+                    defaults={
+                        'email': account.get('email')
+                    }, **lookups)
+                portfolio, unused_created = \
+                    PortfolioDoubleOptIn.objects.update_or_create(
+                        grantee=self.account,
+                        account=account,
+                        campaign=serializer.validated_data.get('campaign'),
+                        defaults=defaults)
+                requests_initiated += [(portfolio, account)]
+
+        for request in requests_initiated:
+            portfolio = request[0]
+            account = request[1]
+            signals.portfolio_request_initiated.send(sender=__name__,
                 portfolio=portfolio, invitee=account, request=self.request)
 
 
