@@ -40,6 +40,7 @@ _SETTINGS = {
     'BELONGS_LOOKUP_FIELD': None,
     'BELONGS_MODEL': None,
     'BELONGS_SERIALIZER': None,
+    'BYPASS_SAMPLE_AVAILABLE': False,
     'CONTENT_MODEL': 'survey.Content',
     'CORRECT_MARKER': '(correct)',
     'DEFAULT_FROM_EMAIL': getattr(settings, 'DEFAULT_FROM_EMAIL', None),
@@ -63,6 +64,7 @@ BELONGS_MODEL = (_SETTINGS.get('BELONGS_MODEL')
 BELONGS_SERIALIZER = (_SETTINGS.get('BELONGS_SERIALIZER')
     if _SETTINGS.get('BELONGS_SERIALIZER')
     else _SETTINGS.get('ACCOUNT_SERIALIZER'))
+BYPASS_SAMPLE_AVAILABLE = _SETTINGS.get('BYPASS_SAMPLE_AVAILABLE')
 CONTENT_MODEL = _SETTINGS.get('CONTENT_MODEL')
 CORRECT_MARKER = _SETTINGS.get('CORRECT_MARKER')
 DEFAULT_FROM_EMAIL = _SETTINGS.get('DEFAULT_FROM_EMAIL')
